==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ja.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "ギャラリー",
    "There was a problem reading files from this album" : "このアルバムからファイルを読み出しに問題がありました。",
    "Aborting preview. Could not find the file" : "プレビューを中止します。ファイルが見つかりませんでした。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "No compatible server found at {remote}" : "互換性のあるサーバーが {remote} にはありません。",
    "Invalid server url" : "サーバーのURLが無効",
    "Gallery view" : "ギャラリー表示",
    "Could not load the description" : "説明を読み出せませんでした",
    "Could not load the description: " : "説明を読み出せませんでした：",
    "Copyright" : "著作権",
    "Could not load the copyright notice: " : "著作権表示を読み出せませんでした：",
    "Copyright notice" : "著作権表示",
    "Link to copyright document" : "著作権表示ドキュメントへリンク",
    "This application may not work properly on your browser." : "このアプリケーションはあなたのブラウザーで正しく動作しないかもしれません。",
    "For an improved experience, please install one of the following alternatives" : "改善された体験のため、以下の選択肢のいずれかインストールしてください",
    "Your browser is not supported!" : "あなたのブラウザーはサポートしていません！",
    "please install one of the following alternatives" : "以下の選択肢のいずれかをインストールしてください",
    "Album cannot be shown" : "アルバムが表示できません",
    "No media files found" : "メディアファイルが見つかりませんでした",
    "Upload pictures in the files app to display them here" : "ファイルアプリから画像をアップロードするとここに表示されます。",
    "Upload new files via drag and drop or by using the [+] button above" : "ドラッグ＆ドロップや [+]ボタンを使って新しいファイルをアップロードしてください。",
    "Configuration error" : "設定エラー",
    "New" : "新規作成",
    "Hide Album" : "アルバムを隠す",
    "Could not hide album" : "アルバムを隠すことができませんでした",
    "Error loading slideshow template" : "スライドショーのテンプレートの読み込みエラー",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>エラー！</strong> このファイルのプレビューを生成できませんでした。<br>スライドショーからこの画像を削除するには次のスライドに移動してください。",
    "Next" : "次",
    "Play" : "再生",
    "Pause" : "一時停止",
    "Previous" : "前",
    "Close" : "閉じる",
    "Download" : "ダウンロード",
    "Toggle background" : "背景の切り替え",
    "Delete" : "削除",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "Upload" : "アップロード",
    "Error" : "エラー",
    "Error while sharing" : "共有でエラー発生",
    "Error while unsharing" : "共有解除でエラー発生",
    "Error while changing permissions" : "権限変更でエラー発生",
    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
    "Shared with you by {owner}" : "{owner} と共有中",
    "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
    "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
    "Share" : "共有",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Federated Cloud ID （ username@example.com/cloud ）を使用して他のサーバー上のユーザーと共有する",
    "Share link" : "URLで共有",
    "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
    "Link" : "リンク",
    "Password protect" : "パスワード保護を有効化",
    "Password" : "パスワード",
    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
    "Allow editing" : "編集を許可",
    "Email link to person" : "メールリンク",
    "Send" : "送信",
    "Set expiration date" : "有効期限を設定",
    "Expiration" : "期限切れ",
    "Expiration date" : "有効期限",
    "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
    "Adding user..." : "ユーザーを追加しています...",
    "group" : "グループ",
    "remote" : "リモート",
    "Resharing is not allowed" : "再共有は許可されていません",
    "Error while retrieving shares" : "共有の取得中にエラーが発生",
    "Unshare" : "共有解除",
    "notify by email" : "メールで通知",
    "can share" : "共有可",
    "can edit" : "編集を許可",
    "access control" : "アクセス権限",
    "create" : "作成",
    "change" : "更新",
    "delete" : "削除",
    "Password protected" : "パスワード保護",
    "Error unsetting expiration date" : "有効期限の未設定エラー",
    "Error setting expiration date" : "有効期限の設定でエラー発生",
    "Sending ..." : "送信中...",
    "Email sent" : "メールを送信しました",
    "Warning" : "警告",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが間違っています。再試行してください。",
    "Sort by date" : "日付で整列",
    "Sort by name" : "名前で整列",
    "Cancel upload" : "アップロードをキャンセル",
    "Album information" : "アルバム情報",
    "File list" : "ファイルリスト",
    "Sorry, this file could not be found." : "申し訳ありません、このファイルは見つかりませんでした。",
    "Reasons might be:" : "理由は以下の通りと考えられます：",
    "the wrong file ID was provided" : "間違ったファイルIDが提供されました",
    "the file was removed" : "ファイルが削除されました",
    "the file is corrupt" : "ファイルが壊れています",
    "the encryption key is missing" : "暗号化キーが欠落しています",
    "Here is the error message returned by the server: " : "サーバーから返されるエラーメッセージ：",
    "For more information, please contact your friendly Nextcloud administrator." : "詳細については、親切なNextcloud管理者にお問い合わせください。",
    "Sorry, but the server could not fulfill your request." : "申し訳ありませんが、サーバーはあなたのリクエストを果たすことができませんでした。",
    "Possible reasons for the problem:" : "問題の考えられる理由：",
    "a conflicting app was installed" : "競合するアプリがインストールされました",
    "a required component is missing or was disconnected" : "必要なコンポーネントが不足しているか切断されました",
    "the filesystem is not readable" : "ファイルシステムは読み込みできません",
    "For more information, please contact your friendly ownCloud administrator." : "詳細については、親切な ownCloud の管理者に連絡してください。",
    "Sorry, this link doesn't seem to work anymore." : "すいません、このリンクはもう利用できません。",
    "the item was removed" : "アイテムが削除されました",
    "the link has expired" : "リンクの期限が切れました",
    "sharing is disabled" : "共有は無効になっています",
    "For more information, please ask the person who has sent you this link." : "詳細については、このリンクを提供者に確認をお願いします。",
    "Add to your Nextcloud" : "あなたのNextcloud に追加",
    "Picture view" : "ピクチャービュー"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ja.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "ギャラリー",
    "There was a problem reading files from this album" : "このアルバムからファイルを読み出しに問題がありました。",
    "Aborting preview. Could not find the file" : "プレビューを中止します。ファイルが見つかりませんでした。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "No compatible server found at {remote}" : "互換性のあるサーバーが {remote} にはありません。",
    "Invalid server url" : "サーバーのURLが無効",
    "Gallery view" : "ギャラリー表示",
    "Could not load the description" : "説明を読み出せませんでした",
    "Could not load the description: " : "説明を読み出せませんでした：",
    "Copyright" : "著作権",
    "Could not load the copyright notice: " : "著作権表示を読み出せませんでした：",
    "Copyright notice" : "著作権表示",
    "Link to copyright document" : "著作権表示ドキュメントへリンク",
    "This application may not work properly on your browser." : "このアプリケーションはあなたのブラウザーで正しく動作しないかもしれません。",
    "For an improved experience, please install one of the following alternatives" : "改善された体験のため、以下の選択肢のいずれかインストールしてください",
    "Your browser is not supported!" : "あなたのブラウザーはサポートしていません！",
    "please install one of the following alternatives" : "以下の選択肢のいずれかをインストールしてください",
    "Album cannot be shown" : "アルバムが表示できません",
    "No media files found" : "メディアファイルが見つかりませんでした",
    "Upload pictures in the files app to display them here" : "ファイルアプリから画像をアップロードするとここに表示されます。",
    "Upload new files via drag and drop or by using the [+] button above" : "ドラッグ＆ドロップや [+]ボタンを使って新しいファイルをアップロードしてください。",
    "Configuration error" : "設定エラー",
    "New" : "新規作成",
    "Hide Album" : "アルバムを隠す",
    "Could not hide album" : "アルバムを隠すことができませんでした",
    "Error loading slideshow template" : "スライドショーのテンプレートの読み込みエラー",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>エラー！</strong> このファイルのプレビューを生成できませんでした。<br>スライドショーからこの画像を削除するには次のスライドに移動してください。",
    "Next" : "次",
    "Play" : "再生",
    "Pause" : "一時停止",
    "Previous" : "前",
    "Close" : "閉じる",
    "Download" : "ダウンロード",
    "Toggle background" : "背景の切り替え",
    "Delete" : "削除",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "Upload" : "アップロード",
    "Error" : "エラー",
    "Error while sharing" : "共有でエラー発生",
    "Error while unsharing" : "共有解除でエラー発生",
    "Error while changing permissions" : "権限変更でエラー発生",
    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
    "Shared with you by {owner}" : "{owner} と共有中",
    "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
    "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
    "Share" : "共有",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Federated Cloud ID （ username@example.com/cloud ）を使用して他のサーバー上のユーザーと共有する",
    "Share link" : "URLで共有",
    "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
    "Link" : "リンク",
    "Password protect" : "パスワード保護を有効化",
    "Password" : "パスワード",
    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
    "Allow editing" : "編集を許可",
    "Email link to person" : "メールリンク",
    "Send" : "送信",
    "Set expiration date" : "有効期限を設定",
    "Expiration" : "期限切れ",
    "Expiration date" : "有効期限",
    "This list is maybe truncated - please refine your search term to see more results." : "このリストは切り捨てられている可能性があります - 検索語句を絞り込んで検索結果を表示してください。",
    "No users or groups found for {search}" : "{search} のユーザー、グループは見つかりません",
    "No users found for {search}" : "{search} のユーザーは見つかりません",
    "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
    "Adding user..." : "ユーザーを追加しています...",
    "group" : "グループ",
    "remote" : "リモート",
    "Resharing is not allowed" : "再共有は許可されていません",
    "Error while retrieving shares" : "共有の取得中にエラーが発生",
    "Unshare" : "共有解除",
    "notify by email" : "メールで通知",
    "can share" : "共有可",
    "can edit" : "編集を許可",
    "access control" : "アクセス権限",
    "create" : "作成",
    "change" : "更新",
    "delete" : "削除",
    "Password protected" : "パスワード保護",
    "Error unsetting expiration date" : "有効期限の未設定エラー",
    "Error setting expiration date" : "有効期限の設定でエラー発生",
    "Sending ..." : "送信中...",
    "Email sent" : "メールを送信しました",
    "Warning" : "警告",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが間違っています。再試行してください。",
    "Sort by date" : "日付で整列",
    "Sort by name" : "名前で整列",
    "Cancel upload" : "アップロードをキャンセル",
    "Album information" : "アルバム情報",
    "File list" : "ファイルリスト",
    "Sorry, this file could not be found." : "申し訳ありません、このファイルは見つかりませんでした。",
    "Reasons might be:" : "理由は以下の通りと考えられます：",
    "the wrong file ID was provided" : "間違ったファイルIDが提供されました",
    "the file was removed" : "ファイルが削除されました",
    "the file is corrupt" : "ファイルが壊れています",
    "the encryption key is missing" : "暗号化キーが欠落しています",
    "Here is the error message returned by the server: " : "サーバーから返されるエラーメッセージ：",
    "For more information, please contact your friendly Nextcloud administrator." : "詳細については、親切なNextcloud管理者にお問い合わせください。",
    "Sorry, but the server could not fulfill your request." : "申し訳ありませんが、サーバーはあなたのリクエストを果たすことができませんでした。",
    "Possible reasons for the problem:" : "問題の考えられる理由：",
    "a conflicting app was installed" : "競合するアプリがインストールされました",
    "a required component is missing or was disconnected" : "必要なコンポーネントが不足しているか切断されました",
    "the filesystem is not readable" : "ファイルシステムは読み込みできません",
    "For more information, please contact your friendly ownCloud administrator." : "詳細については、親切な ownCloud の管理者に連絡してください。",
    "Sorry, this link doesn't seem to work anymore." : "すいません、このリンクはもう利用できません。",
    "the item was removed" : "アイテムが削除されました",
    "the link has expired" : "リンクの期限が切れました",
    "sharing is disabled" : "共有は無効になっています",
    "For more information, please ask the person who has sent you this link." : "詳細については、このリンクを提供者に確認をお願いします。",
    "Add to your Nextcloud" : "あなたのNextcloud に追加",
    "Picture view" : "ピクチャービュー"
},
"nplurals=1; plural=0;");
